## Installation	

⚠️ **ART 4.4** is the last version to support **Python 2.7** & **Python 3.4** officially		

⚠️ **PyPI** support of these versions will be removed in a **future release**

### Source code
- Download [Version 4.9](https://github.com/sepandhaghighi/art/archive/v4.9.zip) or [Latest Source ](https://github.com/sepandhaghighi/art/archive/dev.zip)
- `python3 setup.py install` or `python setup.py install` (Need root access)				

### PyPI


- Check [Python Packaging User Guide](https://packaging.python.org/installing/)     
- `pip install art==4.9` or `pip3 install art==4.9` (Need root access)

* Note :  On `--upgrade` error install latest version of `setuptools` : `pip install setuptools` and retry

### Conda

- Check [Conda Managing Package](https://conda.io)
- `conda install -c sepandhaghighi art ` (Need root access)

### Easy install

- Run `easy_install "art==4.9"` (Need root access)

### MATLAB

- Download and install [MATLAB](https://www.mathworks.com/products/matlab.html) (>=8.5, 64/32 bit)
- Download and install [Python3.x](https://www.python.org/downloads/) (>=3.5, 64/32 bit) 
	- [x] Select `Add to PATH` option
	- [x] Select `Install pip` option
- Run `pip install art` or `pip3 install art` (Need root access)
- Configure Python interpreter
```matlab
>> pyversion PYTHON_EXECUTABLE_FULL_PATH
```
- Visit [MATLAB Examples](https://github.com/sepandhaghighi/art/tree/master/MATLAB)	
